Documentation
¶
Overview ¶
Package for_sqlite provides a sqlite implementation of interfaces in vsafedb package.
Index ¶
- type Store
- func (s Store) AddCategory(t db.Transaction, category *vsafe.Category) error
- func (s Store) AddEntry(t db.Transaction, entry *vsafe.Entry) error
- func (s Store) AddUser(t db.Transaction, user *vsafe.User) error
- func (s Store) CategoriesByOwner(t db.Transaction, owner int64) ([]vsafe.Category, error)
- func (s Store) CategoryById(t db.Transaction, id int64, category *vsafe.Category) error
- func (s Store) EntriesByOwner(t db.Transaction, owner int64, consumer consume2.Consumer[vsafe.Entry]) error
- func (s Store) EntryById(t db.Transaction, id int64, entry *vsafe.Entry) error
- func (s Store) RemoveCategory(t db.Transaction, id int64) error
- func (s Store) RemoveEntry(t db.Transaction, id, owner int64) error
- func (s Store) RemoveUser(t db.Transaction, name string) error
- func (s Store) UpdateCategory(t db.Transaction, category *vsafe.Category) error
- func (s Store) UpdateEntry(t db.Transaction, entry *vsafe.Entry) error
- func (s Store) UpdateUser(t db.Transaction, user *vsafe.User) error
- func (s Store) UserById(t db.Transaction, id int64, user *vsafe.User) error
- func (s Store) UserByName(t db.Transaction, name string, user *vsafe.User) error
- func (s Store) Users(t db.Transaction, consumer consume2.Consumer[vsafe.User]) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Store ¶
type Store struct {
// contains filtered or unexported fields
}
func ConnNew ¶
ConnNew creates a sqlite implementation of the vsafe app datastore from a sqlite connection instance.
func New ¶
func New(db *sqlite3_db.Db) Store
New creates a sqlite implementation of the vsafe app datastore.
func (Store) AddCategory ¶
func (Store) CategoriesByOwner ¶
func (Store) CategoryById ¶
func (Store) EntriesByOwner ¶
func (Store) RemoveCategory ¶
func (s Store) RemoveCategory(t db.Transaction, id int64) error
func (Store) RemoveEntry ¶
func (s Store) RemoveEntry(t db.Transaction, id, owner int64) error
func (Store) RemoveUser ¶
func (s Store) RemoveUser( t db.Transaction, name string) error
func (Store) UpdateCategory ¶
func (Store) UpdateEntry ¶
func (Store) UpdateUser ¶
func (Store) UserByName ¶
Click to show internal directories.
Click to hide internal directories.